@@ -59,6 +59,9 @@ class Event:
                 config = None
             try:
                 if config:
+                    if 'key' in config['handle']:
+                        k= config['handle']['key']
+                    k= self._platformKey+"."+k
                     post_data = {
                         "name": config['handle']['name'],
                         "key": k,
@@ -68,27 +71,31 @@ class Event:
                         "resultChecked": config['handle']['resultChecked']
                     }
                     params_str = {}
-                    for var_name in v.__wrapped__.__code__.co_varnames:
-                        if var_name.lower() == 'args':
-                            params_str[var_name] = {"type": "<class 'tuple'>"}
-                        elif var_name.lower() == "kwargs":
-                            params_str[var_name] = {"type": "<class 'dict'>"}
-                        else:
-                            params_str[var_name] = {"type": "<class 'any'>"}
-                    for var_name, var_value in v.__wrapped__.__annotations__.items():
-                        params_str[var_name]['type'] = str(var_value)
-                    if v.__wrapped__.__defaults__:
-                        for i in range(len(v.__wrapped__.__code__.co_varnames), 0, -1):
-                            if v.__wrapped__.__code__.co_varnames[i-1] == 'args' or v.__wrapped__.__code__.co_varnames[i-1] == 'kwargs':
-                                continue
-                            offset = i - 2
-                            if offset >= 0:
-                                if offset < len(v.__wrapped__.__defaults__):
-                                    params_str[v.__wrapped__.__code__.co_varnames[i-1]
-                                               ]["default"] = v.__wrapped__.__defaults__[offset]
+                    if 'params' not in config['handle']:
+                        parmas_tmp=v.__wrapped__.__code__.co_varnames[0:v.__wrapped__.__code__.co_argcount]
+                        for var_name in parmas_tmp:
+                            if var_name.lower() == 'args':
+                                params_str[var_name] = {"type": "<class 'tuple'>"}
+                            elif var_name.lower() == "kwargs":
+                                params_str[var_name] = {"type": "<class 'dict'>"}
                             else:
-                                break
-                    post_data['params'] = params_str
+                                params_str[var_name] = {"type": "<class 'any'>"}
+                        for var_name, var_value in v.__wrapped__.__annotations__.items():
+                            params_str[var_name]['type'] = str(var_value)
+                        if v.__wrapped__.__defaults__:
+                            for i in range(len(parmas_tmp), 0, -1):
+                                if parmas_tmp[i-1] == 'args' or parmas_tmp[i-1] == 'kwargs':
+                                    continue
+                                offset = i - 2
+                                if offset >= 0:
+                                    if offset < len(v.__wrapped__.__defaults__):
+                                        params_str[parmas_tmp[i-1]
+                                                ]["default"] = v.__wrapped__.__defaults__[offset]
+                                else:
+                                    break
+                        post_data['params'] = params_str
+                    else:
+                        post_data['params']= config['handle']['params']
                     post_data = serializePostData(post_data)
                     state, body = POST(self._event_uri+"handle/", post_data=post_data,
                                        http_headers=self._httpHeaders, time_out=15)
@@ -106,7 +113,7 @@ class Event:
                             logging.error(
                                 "register handle %s is error. %s" % (k, ret['msg']))
                     else:
-                        logging.error("register handle %s is error." % k)
+                        logging.error("access register service failed.%s" % body)
             except Exception as e:
                 logging.error("register handle %s is error, %s" % (k, e))
 
